# An Object-Oriented Python Interface to Singular

[![Continuous Integration Status](https://github.com/GDeLaurentis/syngular/actions/workflows/continuous_integration.yml/badge.svg)](https://github.com/GDeLaurentis/syngular/actions)
[![Coverage](https://img.shields.io/badge/Coverage-93%25-green?labelColor=2a2f35)](https://github.com/GDeLaurentis/syngular/actions)

Requires [Singular](https://www.singular.uni-kl.de/)
